@@ -2,7 +2,7 @@
 """Autoconfigure a Django project from on a github URL.
 
 - downloads the repo
-- creates a virtualenv and installs django (or detects a requirements.txt if available)
+- creates a virtualenv and installs django 1.x (or detects a requirements.txt if available)
 - creates webapp via api
 - creates django wsgi configuration file
 - adds static files config
@@ -28,16 +28,17 @@ def main(repo_url, domain, python_version, nuke):
         username = getpass.getuser().lower()
         domain = f'{username}.pythonanywhere.com'
 
-    project = DjangoProject(domain)
+    project = DjangoProject(domain, python_version)
     project.sanity_checks(nuke=nuke)
+    project.create_webapp(nuke=nuke)
+    project.add_static_file_mappings()
     project.download_repo(repo_url, nuke=nuke),
-    project.create_virtualenv(python_version, nuke=nuke)
+    project.create_virtualenv(nuke=nuke)
     project.find_django_files()
+    project.update_wsgi_file()
     project.update_settings_file()
     project.run_collectstatic()
-    project.create_webapp(nuke=nuke)
-    project.update_wsgi_file()
-    project.add_static_file_mappings()
+    project.run_migrate()
     project.webapp.reload()
 
     print(snakesay(f'All done!  Your site is now live at https://{domain}'))
